import { Switch, Route } from "wouter";
import { lazy, Suspense } from "react";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
import { TooltipProvider } from "@/components/ui/tooltip";
import { useAuth } from "@/hooks/useAuth";
import PerformanceMonitor from "@/components/performance-monitor";
import PerformanceDashboard from "@/components/performance-dashboard";
import MemoryAnalyzer from "@/components/memory-analyzer";
import HelpBot from "@/components/help-bot";
import { Skeleton } from "@/components/ui/skeleton";

// Critical pages loaded immediately
import Home from "@/pages/home";
import Login from "@/pages/login";
import Register from "@/pages/register";
import NotFound from "@/pages/not-found";

// Lazy load non-critical pages for better initial load performance
const PropertyDetail = lazy(() => import("@/pages/property-detail"));
const PostProperty = lazy(() => import("@/pages/post-property"));
const EditProperty = lazy(() => import("@/pages/edit-property"));
const Subscribe = lazy(() => import("@/pages/subscribe"));
const Admin = lazy(() => import("@/pages/admin"));
const AdminDashboard = lazy(() => import("@/pages/admin-dashboard"));
const AdminSitemap = lazy(() => import("@/pages/admin-sitemap"));
const MemberDashboard = lazy(() => import("@/pages/member-dashboard"));
const AffiliatePage = lazy(() => import("@/pages/affiliate"));
const ProfessionalDashboard = lazy(() => import("@/pages/pro-dashboard"));
const AutoLogin = lazy(() => import("@/pages/auto-login"));
const InvestorDemo = lazy(() => import("@/pages/investor-demo"));
const JointVenture = lazy(() => import("@/pages/joint-venture"));
const Search = lazy(() => import("@/pages/search"));
const Calculator = lazy(() => import("@/pages/calculator"));
const Analytics = lazy(() => import("@/pages/analytics"));
const Messages = lazy(() => import("@/pages/messages"));
const BulkInvitations = lazy(() => import("@/pages/bulk-invitations"));
const Join = lazy(() => import("@/pages/join"));
const PropertyLookup = lazy(() => import("@/pages/property-lookup"));
const ForgotPassword = lazy(() => import("@/pages/forgot-password"));
const ResetPassword = lazy(() => import("@/pages/reset-password"));
const Settings = lazy(() => import("@/pages/settings"));
const PaymentHistory = lazy(() => import("@/pages/payment-history"));
const BuyerDashboard = lazy(() => import("@/pages/buyer-dashboard"));
const BulkContacts = lazy(() => import("@/pages/bulk-contacts"));
const Blog = lazy(() => import("@/pages/blog"));
const BlogPost = lazy(() => import("@/pages/blog-post"));
const BlogManagement = lazy(() => import("@/pages/blog-management"));

// Loading fallback component
const PageSkeleton = () => (
  <div className="min-h-screen bg-cream">
    <div className="h-16 bg-white border-b">
      <Skeleton className="h-full w-full" />
    </div>
    <div className="container mx-auto px-4 py-8">
      <Skeleton className="h-8 w-64 mb-6" />
      <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
        {[...Array(6)].map((_, i) => (
          <Skeleton key={i} className="h-64 w-full" />
        ))}
      </div>
    </div>
  </div>
);

function Router() {
  const { isAuthenticated, isLoading } = useAuth();

  if (isLoading) {
    return (
      <div className="h-screen flex items-center justify-center">
        <div className="animate-spin w-8 h-8 border-4 border-primary border-t-transparent rounded-full" aria-label="Loading"/>
      </div>
    );
  }

  return (
    <Suspense fallback={<PageSkeleton />}>
      <Switch>
        <Route path="/" component={Home} />
        <Route path="/login" component={Login} />
        <Route path="/sign-in" component={Login} />
        <Route path="/signin" component={Login} />
        <Route path="/forgot-password" component={ForgotPassword} />
        <Route path="/reset-password" component={ResetPassword} />
        <Route path="/register" component={Register} />
        <Route path="/signup" component={Register} />
        <Route path="/sign-up" component={Register} />
        <Route path="/property/:id" component={PropertyDetail} />
        <Route path="/property/:id/edit" component={EditProperty} />
        <Route path="/post-property" component={PostProperty} />
        <Route path="/subscribe" component={Subscribe} />
        <Route path="/admin" component={Admin} />
        <Route path="/admin-dashboard" component={AdminDashboard} />
        <Route path="/admin/sitemap" component={AdminSitemap} />
        <Route path="/member-dashboard" component={MemberDashboard} />
        <Route path="/pro-dashboard" component={ProfessionalDashboard} />
        <Route path="/affiliate" component={AffiliatePage} />
        <Route path="/auto-login" component={AutoLogin} />
        <Route path="/investor-demo" component={InvestorDemo} />
        <Route path="/joint-venture" component={JointVenture} />
        <Route path="/search" component={Search} />
        <Route path="/calculator" component={Calculator} />
        <Route path="/analytics" component={Analytics} />
        <Route path="/messages" component={Messages} />
        <Route path="/bulk-invitations" component={BulkInvitations} />
        <Route path="/join" component={Join} />
        <Route path="/property-lookup" component={PropertyLookup} />
        <Route path="/buyer-dashboard" component={BuyerDashboard} />
        <Route path="/bulk-contacts" component={BulkContacts} />
        <Route path="/settings" component={Settings} />
        <Route path="/payment-history" component={PaymentHistory} />
        <Route path="/blog" component={Blog} />
        <Route path="/blog/:id" component={BlogPost} />
        <Route path="/admin/blog-management" component={BlogManagement} />
        <Route component={NotFound} />
      </Switch>
    </Suspense>
  );
}

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      <TooltipProvider>
        <PerformanceMonitor />
        <Toaster />
        <Router />
      </TooltipProvider>
    </QueryClientProvider>
  );
}

export default App;